#!/usr/bin/env python

"""pdf_split.py
"""

import os, sys
sys.path.insert(0, os.path.dirname(sys.argv[0]))

from pageCatcher import storeForms, restoreForms
from reportlab.pdfgen import canvas


def split0(inPath):
    "Split a multi-page PDF file into multiple one-page files."

    splitext = os.path.splitext
    storageFile = inPath + ".data"
    page = 0

    while 1:
        try:
            X = storeForms(inPath, storageFile, [page], BBoxes=1)
        except IndexError:
            break

        bbox = X['PageForms%d' % page]
        outPath = "%s_page%d.pdf" % (splitext(inPath)[0], page)
        canv = canvas.Canvas(outPath, pagesize=tuple(bbox[2:]))
        names = restoreForms(storageFile, canv)
        canv.doForm(names[0])
        canv.showPage()
        canv.save()
        page = page + 1
        
    os.remove(storageFile)


def split1(inPath):
    "Split a multi-page PDF file into multiple one-page files."

    splitext = os.path.splitext
    storageFile = inPath + ".data"
    page = 0

    storeForms(inPath, storageFile, prefix="page", BBoxes=1, all=1)

    while 1:
        outPath = "%s_page%d.pdf" % (splitext(inPath)[0], page)
        canv = canvas.Canvas(outPath, pagesize=tuple(bbox[2:]))
        names = restoreForms(storageFile, canv)
        print names
        canv.doForm(names[0])
        canv.showPage()
        canv.save()
        page = page + 1

    os.remove(storageFile)


def split(inPath):
    "Split a multi-page PDF file into multiple one-page files."
    
    # Should be much faster than the previous versions above.

    splitext = os.path.splitext
    storageFile = inPath + ".data"

    X = storeForms(inPath, storageFile, prefix="", BBoxes=1, all=1)
    items = X.items()
    items.sort()

    for page in range(len(items)):
        num, bbox = items[page]        
        outPath = "%s_page%d.pdf" % (splitext(inPath)[0], page)
        canv = canvas.Canvas(outPath, pagesize=tuple(bbox[2:]))
        names = restoreForms(storageFile, canv)
        canv.doForm(names[page])
        canv.showPage()
        canv.save()
        page = page + 1

    os.remove(storageFile)


if __name__=='__main__':
    # command-line usage: python pdfsplit.py <pdfFile>
    split1(sys.argv[1])
